==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-admin/lxqt-admin-time/lxqt-admin-time_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>DateTime</name>
    <message>
        <location filename="../../../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>Tijd:</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translatorcomment>No need to translate. → Agree. Copying the English string nevertheless in order to avoid superfluos tagging as unfinished.</translatorcomment>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>Datum:</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="89"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Het opslaan van wijzigingen vergt rootrechten.&lt;br&gt;na het klikken op de afsluitknop zal u daarom worden verzocht.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="42"/>
        <source>Time and date configuration</source>
        <translation>Tijd en datum instellen</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="53"/>
        <source>Date and time</source>
        <translation>Datum en tijd</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="62"/>
        <source>Timezone</source>
        <translation>Tijdzone</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="162"/>
        <source>Authentication Error</source>
        <translation>Authenticatiefout</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <location filename="../../../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>Uw huidige tijdzone:</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="26"/>
        <source>TextLabel</source>
        <translation>Tekstveld</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="35"/>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="54"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Het opslaan van de wijzigingen vergt rootrechten.&lt;br&gt;Na het drukken op de afsluitknop zal u daarom worden verzocht.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-admin/lxqt-admin-time/lxqt-admin-time_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>DateTime</name>
    <message>
        <location filename="../../../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>Tijd:</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translatorcomment>No need to translate. → Agree. Copying the English string nevertheless in order to avoid superfluos tagging as unfinished.</translatorcomment>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>Datum:</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="70"/>
        <source>Enable network time synchronization (NTP)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="77"/>
        <source>RTC is in local time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Het opslaan van wijzigingen vergt rootrechten.&lt;br&gt;na het klikken op de afsluitknop zal u daarom worden verzocht.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="42"/>
        <source>Time and date configuration</source>
        <translation>Tijd en datum instellen</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="48"/>
        <source>Date and time</source>
        <translation>Datum en tijd</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="56"/>
        <source>Timezone</source>
        <translation>Tijdzone</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="117"/>
        <location filename="../../../timeadmindialog.cpp" line="127"/>
        <location filename="../../../timeadmindialog.cpp" line="134"/>
        <location filename="../../../timeadmindialog.cpp" line="144"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication Error</source>
        <translation type="vanished">Authenticatiefout</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <location filename="../../../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>Uw huidige tijdzone:</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="26"/>
        <source>TextLabel</source>
        <translation>Tekstveld</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="35"/>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Het opslaan van de wijzigingen vergt rootrechten.&lt;br&gt;Na het drukken op de afsluitknop zal u daarom worden verzocht.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">Geen</translation>
    </message>
</context>
<context>
    <name>TimezonePage</name>
    <message>
        <location filename="../../../timezone.cpp" line="42"/>
        <source>None</source>
        <translation type="unfinished">Geen</translation>
    </message>
</context>
</TS>
